
{*******************************************************}
{                                                       }
{       Delphi Visual Component Library                 }
{                                                       }
{       Copyright (c) 1995 Borland International        }
{                                                       }
{*******************************************************}

unit ChartFX;

interface

uses WinTypes, WinProcs, SysUtils;

{ Function Prototypes }
var
  chart_Send: function(hWnd: Integer; wMsg: Integer; wParam: Integer;
    lParam: Longint): Longint;
  chart_Get: function(hWnd: Integer; lType: Longint; wCode: Integer): Double;
  chart_SetStripe: function(hWnd: Integer; nIndex: Integer; dIni: Double;
    dEnd: Double; lColor: Longint): Longint;
  chart_SetStatusItem:function(hWnd: Integer; n: Integer; Text: Boolean;
    idm: Integer; Frame: Boolean; w:Integer; min: Integer; desp:Integer;
    s: Longint): Longint;
  chart_Paint:procedure(hWnd: Integer; hDC: Integer; xLeft: Integer;
    yTop: Integer; xRight: Integer; yBottom: Integer; bPrintMode: Integer;
    l: Longint);

{ Notification Codes }
const
  CCC_SERIE = 0;
  CCC_SERIEBK = 1;
  CCC_ONE = 2;
  CCC_ONEBK = 3;
  CCC_BARHORZ = 4;
  CCC_BKGND = 5;
  CCC_2DBK = 6;
  CCC_3DBK = 7;

  CCS_LEGEND = 0;
  CCS_SERLEGEND = 1;

  CCP_SERIE = 0;
  CCP_ONE = 1;

{ Gallery Types }
  LINES = 1;
  BAR = 2;
  SPLINE = 3;
  MARK = 4;
  PIE = 5;
  AREA = 6;
  PARETO = 7;
  SCATTER = 8;
  HILOW = 9;

{ Chart Types }
  CT_3D = $00000100;
  CT_HORZ = $00000200;
  CT_TOOL = $00000400;
  CT_PALETTE = $00000800;
  CT_LEGEND = $00001000;
  CT_TOGETHER = $00002000;
  CT_POINTS = $00004000;
  CT_SHOWZERO = $00008000;
  CT_EACHBAR = $00010000;
  CT_CLUSTER = $00020000;
  CT_SHOWDATA = $00040000;
  CT_DLGGRAY = $00080000;
  CT_PATTERN = $00100000;
  CT_SHOWVALUES = $00200000;
  CT_MENU = $00400000;
  CT_SCATTERLINE	= $00800000;
  CT_COLORLINE =	$01000000;
  CT_NOAREALINE = $02000000;
  CT_NOBORDERS = $04000000;
  CT_PIEVALUES = $08000000;

{ Chart Styles }
  CS_CHLINE = $00000001;
  CS_CHBAR = $00000002;
  CS_CHSPLINE = $00000004;
  CS_CHMARK = $00000008;
  CS_CHPIE = $00000010;
  CS_CHAREA = $00000020;
  CS_CHPARETO = $00000040;
  CS_CHSCATTER = $00000080;
  CS_CHHILOW = $00000100;
  CS_CHDEFAULT = $00000FFF;
  CS_MINMAX = $00001000;
  CS_3D = $00002000;
  CS_HORZ = $00004000;
  CS_TOGETHER = $00008000;
  CS_SHOWPOINT = $00010000;
  CS_SCALE = $00020000;
  CS_TITLES = $00040000;
  CS_FONTS = $00080000;
  CS_EDITABLE = $00100000;
  CS_FILEEXPORT = $00200000;
  CS_FILEIMPORT = $00400000;
  CS_SCROLLABLE = $00800000;
  CS_PRINTABLE = $01000000;
  CS_3DVIEW = $02000000;
  CS_GRID = $04000000;
  CS_RESIZEABLE = $08000000;
  CS_TEMPLATE = $10000000;
  CS_COPY = $20000000;
  CS_CLOSEABLE = $40000000;
  CS_ALL = $FFFFFFFF;

{ Constants }

{ STYLE, TYPE }
  CHART_ADD = 0;
  CHART_SET = 1;
  CHART_REMOVE = 2;

{ STACKED }
  CHART_NOSTACKED = 0;
  CHART_STACKED = 1;
  CHART_STACKED100 = 2;

{ GRID }
  CHART_NOGRID = 0;
  CHART_HORZGRID = 1;
  CHART_VERTGRID = 2;
  CHART_BOTHGRID = 3;

{ POINTTYPE }
  CHART_NONEMK = 0;
  CHART_RECTMK = 1;
  CHART_CIRCLEMK = 2;
  CHART_TRIANGLEMK = 3;
  CHART_MARBLEMK = 4;
  CHART_CUBEMK = 5;
  CHART_MANYMK = 6;

{ TITLES }
  CHART_LEFTTIT = 0;
  CHART_RIGHTTIT = 1;
  CHART_TOPTIT = 2;
  CHART_BOTTOMTIT = 3;

{ FONTS }
  CHART_LEFTFT = 0;
  CHART_RIGHTFT = 1;
  CHART_TOPFT = 2;
  CHART_BOTTOMFT = 3;
  CHART_XLEGFT = 4;
  CHART_YLEGFT = 5;
  CHART_FIXEDFT = 6;
  CHART_LEGENDFT = 7;

{ Types of DBLCLK o RIGCLK }
  CHART_BALOONCLK = 0;
  CHART_DIALOGCLK = 1;
  CHART_NONECLK = 2;
  CHART_MENUCLK = 3;

{ GAP }
  CHART_LEFTGAP = 0;
  CHART_RIGHGAP = 1;
  CHART_TOPGAP = 2;
  CHART_BOTTOMGAP = 3;
  CHART_ALLGAP = 4;

{ Colors }
  CHART_WHITE = 1;
  CHART_BLACK = 2;
  CHART_LTGRAY = 3;
  CHART_DKGRAY = 4;
  CHART_RED = 5;
  CHART_DKRED = 6;
  CHART_BLUE = 7;
  CHART_DKBLUE = 8;
  CHART_GREEN = 9;
  CHART_DKGREEN = 10;
  CHART_CYAN = 11;
  CHART_DKCYAN = 12;
  CHART_YELLOW = 13;
  CHART_DKYELLOW = 14;
  CHART_VIOLET = 15;
  CHART_DKVIOLET = 16;

{ Line Styles }
  CHART_SOLID = 0;
  CHART_DASH = 1;
  CHART_DOT = 2;
  CHART_DASHDOT = 3;
  CHART_DASHDOTDOT = 4;

{ Color Schemes }
  CHART_CSSOLID = 0;
  CHART_CSBWPATTERN = 1;
  CHART_CSPATTERN = 2;

{ Color Types }
  CHART_FGROUND = 0;
  CHART_BGROUND = 1;

{ ChartStatus Property constants }
  CHART_GSVALUES = $00000001;
  CHART_GSLEGENDS = $00000002;
  CHART_GSCOLORS = $00000004;
  CHART_GSPATTERNS = $00000008;
  CHART_GSPALETTE = $00000010;
  CHART_GSPATTPAL = $00000020;
  CHART_GSREADTEMP = $00000040;
  CHART_GSREADFILE = $00000080;
  CHART_GSGALLERY = $00000100;
  CHART_GSOPTIONS = $00000200;

{ FONTS }
  CF_BOLD = $00000100;
  CF_ITALIC = $00000200;
  CF_UNDERLINE = $00000400;
  CF_STRIKEOUT = $00000800;
  CF_FDONTCARE = $00000000;
  CF_FROMAN = $00001000;
  CF_FSWISS = $00002000;
  CF_FMODERN = $00003000;
  CF_FSCRIPT = $00004000;
  CF_FDECORATIVE = $00005000;
  CF_ARIAL = $00000000;
  CF_COURIER = $00010000;
  CF_COURIERNEW = $00020000;
  CF_HELVETICA = $00030000;
  CF_MODERN = $00040000;
  CF_ROMAN = $00050000;
  CF_SCRIPT = $00060000;
  CF_SYMBOL = $00070000;
  CF_TIMES = $00080000;
  CF_TIMESNEWR = $00090000;
  CF_WINGDINGS = $000A0000;

{ OpenData indexes }
  COD_VALUES = 1;
  COD_CONSTANTS = 2;
  COD_COLORS = 3;
  COD_STRIPES = 4;
  COD_INIVALUES = 5;
  COD_XVALUES = 6;
  COD_STATUSITEMS = 7;

{ Closedata actions }
  COD_SMOOTH = $1000;
  COD_UNKNOWN = $FFFF;
  COD_UNCHANGE = 0;

{ Adm indexes }
  CSA_MIN = 0;
  CSA_MAX = 1;
  CSA_GAP = 2;
  CSA_SCALE = 3;
  CSA_YLEGGAP = 4;
  CSA_PIXXVALUE = 5;
  CSA_XMIN = 6;
  CSA_XMAX = 7;

{ XLEGTYPE }
  CL_NOTCLIPPED = $0001;
  CL_NOTCHANGECOLOR = $0002;
  CL_HIDE = $0004;
  CL_FORCESERLEG = $0008;
  CL_GETLEGEND = $0010;
  CC_HIDETEXT = $0001;
  CC_HIDE = $0002;

{ ITEM[STYLE | COLOR | WIDTH] }
  CI_HORZGRID = 0;
  CI_VERTGRID = 1;

{ DECIMALSNUM }
  CD_ALL = 0;
  CD_VALUES = 1;
  CD_YLEG = 2;
  CD_XLEG = 3;

{ SHOWDIALOG }
  CDIALOG_EXPORTFILE = 14;
  CDIALOG_IMPORTFILE = 15;
  CDIALOG_WRITETEMPLATE = 8;
  CDIALOG_READTEMPLATE = 9;
  CDIALOG_PAGESETUP = 4;
  CDIALOG_ABOUT = 11;
  CDIALOG_OPTIONS = 12;
  CDIALOG_EDITTITLES = 35;
  CDIALOG_FONTS = 39;
  CDIALOG_ROTATE = 52;

{ StatusBar Item Structure }
type
  CHART_STITEM = record
    sText: string;
    wIdm: Integer;
    bFrame: Integer;
    nWidth: Integer;
    nMin: Integer;
    nDesp: Integer;
    dwStyle: Longint;
  end;

{ Status Item Styles }
const
  CHART_STLEFT = $0000;
  CHART_STCENTER = $0001;
  CHART_STRIGHT = $0002;

{ HILOW Constants }
  HLC_HIGH = 0;
  HLC_CLOSE = 1;
  HLC_LOW = 2;

  OHLC_CLOSE = 0;
  OHLC_HIGH = 1;
  OHLC_OPEN = 2;
  OHLC_LOW = 3;

{ SetTool Constants }
  CST_IMPORT = $00000001;
  CST_EXPORT = $00000002;
  CST_COPYBITMAP = $00000004;
  CST_COPYDATA = $00000008;
  CST_PRINT = $00000010;
  CST_SPACE1 = $00000020;
  CST_AREA = $00000040;
  CST_BARHORZ = $00000080;
  CST_BAR = $00000100;
  CST_LINE = $00000200;
  CST_MARK = $00000400;
  CST_PIE = $00000800;
  CST_SPLINE = $00001000;
  CST_PARETO = $00002000;
  CST_SCATTER = $00004000;
  CST_HILOW = $00008000;
  CST_SPACE2 = $00010000;
  CST_3D = $00020000;
  CST_ROTATE = $00040000;
  CST_CLUSTER = $00080000;
  CST_SPACE3 = $00100000;
  CST_LEGEND = $00200000;
  CST_VGRID = $00400000;
  CST_HGRID = $00800000;
  CST_SPACE4 = $01000000;
  CST_TITLES = $02000000;
  CST_FONTS = $04000000;
  CST_TOOLS = $08000000;
  CST_OPTIONS = $10000000;
  CST_FILE = (CST_IMPORT Or CST_EXPORT);
  CST_COPY = (CST_COPYBITMAP Or CST_COPYDATA);
  CST_FILEEDIT = (CST_FILE Or CST_COPY Or CST_PRINT);
  CST_GALLERY = (CST_AREA Or CST_BARHORZ Or CST_BAR Or CST_LINE Or CST_MARK Or CST_PIE Or CST_SPLINE);
  CST_GALLERYEXT = (CST_GALLERY Or CST_PARETO Or CST_SCATTER Or CST_HILOW);
  CST_VIEW = (CST_3D Or CST_ROTATE Or CST_CLUSTER);
  CST_LEGGRID = (CST_LEGEND Or CST_VGRID Or CST_HGRID);
  CST_OTHER = (CST_TITLES Or CST_FONTS Or CST_TOOLS Or CST_OPTIONS);

implementation

var
  hCFXHandle: THandle;

procedure SFX_CFXEnd; far;
begin
  FreeLibrary(hCFXHandle);
end;

begin
  hCFXHandle := LoadLibrary('chart2fx.vbx');
  AddExitProc(SFX_CFXEnd);

  @chart_Send := GetProcAddress(hCFXHandle, 'chart_Send');
  @chart_Get := GetProcAddress(hCFXHandle, 'chart_Get');
  @chart_SetStatusItem := GetProcAddress(hCFXHandle, 'chart_SetStatusItem');
  @chart_SetStripe := GetProcAddress(hCFXHandle, 'chart_SetStripe');
  @chart_Paint := GetProcAddress(hCFXHandle, 'chart_Paint');
end.
